@@ -1,6 +1,7 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
     SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2018-2022 Alexander Semke <alexander.semke@web.de>
 */
 
 #ifndef _REXPRESSION_H
@@ -18,13 +19,14 @@ class RExpression : public Cantor::Expression
 
     void evaluate() override;
     void interrupt() override;
-    void parseOutput(const QString& text);
-    void parseError(const QString& text);
-    void showFilesAsResult(const QStringList& files);
+    void parseOutput(const QString&) override;
+    void parseError(const QString&) override;
+    void showFilesAsResult(const QStringList&);
 
     void addInformation(const QString&) override;
+
   private:
-    bool m_isHelpRequest;
+    bool m_isHelpRequest{false};
 };
 
 #endif /* _REXPRESSION_H */
