@@ -15,11 +15,14 @@
     Boston, MA  02110-1301, USA.
 
     ---
-    Copyright (C) 2020-2022 Alexander Semke <alexander.semke@web.de>
+    Copyright (C) 2020-2024 Alexander Semke <alexander.semke@web.de>
  */
 
 #include "backendsettingswidget.h"
+
+#ifdef HAVE_EMBEDDED_DOCUMENTATION
 #include "qthelpconfig.h"
+#endif
 
 #include <QFile>
 #include <QHBoxLayout>
@@ -33,7 +36,11 @@ BackendSettingsWidget::BackendSettingsWidget(QWidget* parent, const QString& id)
 }
 
 void BackendSettingsWidget::tabChanged(int index) {
-    if (!m_tabWidget || !m_tabDocumentation)
+    if (!m_tabWidget)
+        return;
+
+#ifdef HAVE_EMBEDDED_DOCUMENTATION
+    if (!m_tabDocumentation)
         return;
 
     //if the documentation tab was selected and there is not doc widget available yet, create it
@@ -46,18 +53,20 @@ void BackendSettingsWidget::tabChanged(int index) {
             hboxLayout->addWidget(m_docWidget);
         }
     }
+#endif
 }
 
 void BackendSettingsWidget::fileNameChanged(const QString& fileName) {
     if (!m_urlRequester)
         return;
 
-    bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
-    if (invalid) {
-        QPalette p;                                                                                                                                            \
-        if (qGray(p.color(QPalette::Base).rgb()) > 160) /* light */                                                                                            \
-            m_urlRequester->setStyleSheet(QLatin1String("background: rgb(255, 200, 200);"));                                                                             \
-        else /* dark */                                                                                                                                        \
+    const bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
+    if (invalid)
+    {
+        QPalette p;
+        if (qGray(p.color(QPalette::Base).rgb()) > 160) /* light */
+            m_urlRequester->setStyleSheet(QLatin1String("background: rgb(255, 200, 200);"));
+        else /* dark */
             m_urlRequester->setStyleSheet(QLatin1String("background: rgb(128, 0, 0);"));
     }
     else
